import colorful

from pure import colors


def test_base_colors():
    assert str(colors.primary('foo')) == str(colorful.purple1('foo'))
    assert str(colors.info('foo')) == str(colorful.lightBlue('foo'))
    assert str(colors.mute('foo')) == str(colorful.gray('foo'))
    assert str(colors.success('foo')) == str(colorful.green('foo'))
    assert str(colors.normal('foo')) == str(colorful.darkGray('foo'))
    assert str(colors.danger('foo')) == str(colorful.red3('foo'))
    assert str(colors.light('foo')) == str(colorful.white('foo'))
    assert str(colors.warning('foo')) == str(colorful.orange('foo'))
    assert str(colors.dark('foo')) == str(colorful.black('foo'))


import argparse
import os

import git

from pure import colors

SUCCESS = 0


def prompt_symbol(last_command_status=SUCCESS):
    symbol = colors.primary('❯') if last_command_status == SUCCESS else colors.danger('❯')
    return symbol


def current_working_path():
    return colors.info(os.getcwd()) 


def virtual_env():
    if 'VIRTUAL_ENV' in os.environ:
        virtual_env_name = os.path.basename(os.environ['VIRTUAL_ENV'])
        return colors.mute('{} '.format(virtual_env_name))
    return ''


def git_active_branch(directory):
    try:
        repo = git.Repo(directory)
        return colors.mute(str(repo.active_branch))
    except Exception:
        return ''


def git_is_dirty(directory):
    try:
        repo = git.Repo(directory)
        return colors.mute('*') if repo.is_dirty(untracked_files=True) else ''
    except Exception:
        return ''


def layout():
    return "\n{current_working_path} {git_active_branch}{git_is_dirty}\n{virtual_env}{prompt_symbol} "


def prompt(args):
    data = {
        'current_working_path': current_working_path(), 
        'git_active_branch': git_active_branch(os.getcwd()), 
        'git_is_dirty': git_is_dirty(os.getcwd()), 
        'virtual_env': virtual_env(), 
        'prompt_symbol': prompt_symbol(args.last_command_status)
    }
    print(layout().format(**data))


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='Process shell variables.')
    parser.add_argument('last_command_status', type=int, help='last command\'s exit status')

    prompt(parser.parse_args())



import colorful

colorful.use_true_colors()

primary = colorful.purple1
info = colorful.lightBlue
mute = colorful.gray
success = colorful.green
normal = colorful.darkGray
danger = colorful.red3
light = colorful.white
warning = colorful.orange
dark = colorful.black



import os
from pathlib import Path
import tempfile

import git
from pure import prompt, colors

SUCCESS = 0
FAIL = 1


def test_contains_prompt_symbol():
    assert '❯' in prompt.prompt_symbol()


def test_prompt_symbol_is_colored_for_successful_command():
    assert str(prompt.prompt_symbol()) == str(colors.primary('❯'))
    assert str(prompt.prompt_symbol()) == '\x1b[38;2;155;48;255m❯\x1b[39m'


def test_contains_path():
    os.chdir(str(Path('/tmp')))
    assert '/tmp' in str(prompt.current_working_path())


def test_current_working_path_color_is_info():
    os.chdir(str(Path('/tmp')))
    assert str(prompt.current_working_path()) == str(colors.info('/tmp'))
    assert str(prompt.current_working_path()) == '\x1b[38;2;173;216;230m/tmp\x1b[39m'


def test_change_prompt_when_last_command_fail():
    assert '❯' in prompt.prompt_symbol(last_command_status=SUCCESS)
    assert '❯' in prompt.prompt_symbol(last_command_status=FAIL)


def test_prompt_symbol_is_colored_for_failed_command():
    assert str(prompt.prompt_symbol(last_command_status=FAIL)) == str(colors.danger('❯'))
    assert str(prompt.prompt_symbol(last_command_status=FAIL)) == '\x1b[38;2;205;0;0m❯\x1b[39m'


def test_displays_virtual_env_invisible_when_deactivated():
    os.unsetenv('VIRTUAL_ENV')
    if 'VIRTUAL_ENV' in os.environ: # when running tests in a virtualenv
        del os.environ['VIRTUAL_ENV']

    assert prompt.virtual_env() == ''


def test_displays_virtual_env_when_activated():
    os.environ['VIRTUAL_ENV'] = '/path/to/virtual/env'

    assert 'env' in str(prompt.virtual_env())
    assert str(prompt.virtual_env()) == str(colors.mute('env '))

def test_prompt_layout():
    assert prompt.layout() == "\n{current_working_path} {git_active_branch}{git_is_dirty}\n{virtual_env}{prompt_symbol} "

def test_contains_git_branch_name():
    with tempfile.TemporaryDirectory() as tmp_repo:
        empty_repo = git.Repo.init(tmp_repo)

        assert 'master' in str(prompt.git_active_branch(tmp_repo))
        
def test_git_branch_name_color_is_mute():
    with tempfile.TemporaryDirectory() as tmp_repo:
        empty_repo = git.Repo.init(tmp_repo)

        assert str(prompt.git_active_branch(tmp_repo)) == str(colors.mute('master'))

def test_displays_when_repo_is_dirty():
    with tempfile.TemporaryDirectory() as tmp_repo:
        empty_repo = git.Repo.init(tmp_repo)
        new_file = tempfile.NamedTemporaryFile(dir=tmp_repo)

        assert '*' in str(prompt.git_is_dirty(tmp_repo))
        new_file.close()

def test_repo_is_dirty_color_is_mute():
    with tempfile.TemporaryDirectory() as tmp_repo:
        empty_repo = git.Repo.init(tmp_repo)
        new_file = tempfile.NamedTemporaryFile(dir=tmp_repo)

        assert str(prompt.git_is_dirty(tmp_repo)) == str(colors.mute('*'))

        new_file.close()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pure",
    version="1.4.1",
    author="Édouard Lopez",
    author_email="contact@edouard-lopez.com",
    description="Pretty, minimal and fast prompt for various shells",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/edouard-lopez/pure",
    packages=setuptools.find_packages(),
    classifiers=[
        'Topic :: System :: Shells',
        "Operating System :: OS Independent",
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        'Operating System :: POSIX',
        'Natural Language :: English',
        'Topic :: Terminals',
        'Environment :: Console',
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)